Learn R Programming

spatstat.utils (version 3.2-5)

do.call.without: Call a Function, Omitting Certain Arguments

Description

Call a specified function, omitting some arguments which are inappropriate to the function.

Usage

do.call.without(fun, ..., avoid, envir=parent.frame())

Arguments

Value

The return value of fun.

Details

This is a simple mechanism for preventing some arguments from being passed in a function call. The arguments ... are collected in a list. A argument is omitted if its name exactly matches one of the strings in avoid.

See Also

do.call.matched for a more complicated and flexible call.

Examples

Run this code
  do.call.without(paste, 1, 2, z=3, w=4, avoid="z")

Run the code above in your browser using DataLab