Learn R Programming

spatstat.utils (version 3.2-5)

paren: Add or Remove Parentheses

Description

Add or remove enclosing parentheses around a string.

Usage

paren(x, type = "(")
unparen(x)

Arguments

Value

A character string, or vector of character strings of the same length as x.

Details

paren(x) adds enclosing parentheses to the beginning and end of the string x.

unparen(x) removes enclosing parentheses if they are present.

See Also

commasep

Examples

Run this code
  paren("Hello world")
  paren(42, "[")
  paren(letters[1:10])
  unparen(c("(yes)", "[no]", "{42}"))

Run the code above in your browser using DataLab